cumulusci.tasks package
=======================

Subpackages
-----------

.. toctree::

    cumulusci.tasks.apex
    cumulusci.tasks.github
    cumulusci.tasks.metadata
    cumulusci.tasks.push
    cumulusci.tasks.release_notes
    cumulusci.tasks.robotframework
    cumulusci.tasks.tests

Submodules
----------

cumulusci.tasks.apexdoc module
------------------------------

.. automodule:: cumulusci.tasks.apexdoc
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.bulkdata module
-------------------------------

.. automodule:: cumulusci.tasks.bulkdata
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.command module
------------------------------

.. automodule:: cumulusci.tasks.command
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metaxml module
------------------------------

.. automodule:: cumulusci.tasks.metaxml
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.mrbelvedere module
----------------------------------

.. automodule:: cumulusci.tasks.mrbelvedere
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce module
---------------------------------

.. automodule:: cumulusci.tasks.salesforce
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.sfdx module
---------------------------

.. automodule:: cumulusci.tasks.sfdx
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.util module
---------------------------

.. automodule:: cumulusci.tasks.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks
    :members:
    :undoc-members:
    :show-inheritance:
